California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 027 - ELIMINATES STATE COMMISSION ON REDISTRICTING. CONSOLIDATES AUTHORITY FOR REDISTRICTING WITH ELECTED REPRESENTATIVES. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1319411 | TRUEPAC - CONCERNED CITIZENS INCLUDING JUDY CHU TO SUPPORT PROPOSITION 27 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1329182 | CALIFORNIA COALITION FOR LEADERSHIP AND ACCOUNTABILITY IN BUDGET AND REDISTRICTING, YES ON 25 & 27, NO ON 20 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1323672 | YES ON FAIR, YES ON 27, NO ON 20--A COALITION OF ENTREPERNEURS, WORKING PEOPLE, BUSINESSES, COMMUNITY LEADERS SUCH AS KAREN BASS, & OTHER CONCERNED CITIZENS DEVOTED TO ELIMINATING BUREAUCRATIC WASTE.. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1331971 | NO ON 27 - KEEP VOTERS FIRST, A COALITION OF GOOD GOVERNMENT GROUPS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1321618 | YES ON 20, NO ON 27 - HOLD POLITICIANS ACCOUNTABLE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1270683 | SMALL BUSINESS ACTION COMMITTEE PAC, YES ON 20 & 26, NO ON 25 & 27 | OPPOSE